"""Module containing logging config names enum."""

# Standard libs
from enum import Enum


# pylint: disable=too-few-public-methods
class AppLoggerConfigName(Enum):
    """Class to define logging config names enum value pair."""

    DEFAULT_FORMAT_1 = "default_format_1"
